// emacs: this is -*- c++ -*-
//
//   basic_pdf.h  pdf transform class for basic 121 ( 11 x 11 ) of 
//                incoming parton combinations (not including a top 
//                density) the 121 different sub processes correspond 
//                to flavour combinations of where the first parton 
//                if from proton 1 and the second from proton 2 of
//
//                  0 - bbar-bbar
//                  1 - bbar-cbar
//                  2 - bbar-sbar 
//                  ...
//                  120 - b-b
//                    
//                The flavours are in the standard lhapdf convention:
//                  -6 (tbar) to +6 (top) with the gluon, flavour 0  
//                    
// 
//   Copyright (C) 2007 M.Sutton (sutt@hep.ucl.ac.uk)    
//
//   $Id: basic_pdf.h, v1.0   Mon Dec 10 01:36:04 GMT 2007 sutt $



#ifndef BASIC_PDF_H
#define BASIC_PDF_H


#include "appl_grid/appl_pdf.h" 


// basic pdf combination class
class basic_pdf : public appl::appl_pdf {

public:

  basic_pdf() : appl::appl_pdf("basic") { m_Nproc=121; } 

  void evaluate(const double* f1, const double* f2, double* H);

  int  decideSubProcess(const int iflav1, const int iflav2);

};  
  


inline void basic_pdf::evaluate(const double* _f1, const double* _f2, double* H) {  

  // remapping from pdg -6..6 convention to u..t ubar..tbar g internal
  // basic convention

  const double* f1 = _f1+6;
  const double* f2 = _f1+6;

  ///  double H[121]; /// do not include top: 11x11 rather than 13x13
  int ih=0;
  /// from -b to b rather than -t to t
  for ( int i=-5 ; i<=5 ; i++ )  { 
    for ( int j=-5 ; j<=5 ; j++ )  { 
      /// f1 partons first !!! 
      H[ih++] = f1[i]*f2[j];
    }
  }
}
  

inline int  basic_pdf::decideSubProcess(const int iflav1, const int iflav2) { 
  if ( std::abs(iflav1)>5 || std::abs(iflav2)>5 ) return -1;
  return (iflav1+5)*11+(iflav2+5);
}



// fortran callable wrapper
extern "C" void fbasic_pdf__(const double* fA, const double* fB, double* H);


#endif // BASIC_PDF_H

